@@ -23,5 +23,5 @@ def preprocess(data, params):
     if params['gaussian_laplace']:
         im = gaussian(laplace(im),2)
     im = im if params['scale']==1 else rescale(im,params['scale'],preserve_range=True)
-    im = add_noise(im,params['sensitivity']) if params['local_noise'] else random_noise(im,mode = 'gaussian',var = params['sensitivity'])
+    im = add_noise(im,params['sensitivity']) if params['local_noise'] else random_noise(im,mode = 'gaussian',var = params['sensitivity']/100.0)
     return im
\ No newline at end of file
